<?php 
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class sp_admin {

	/**
	 * Agregar las paginas administrativas del plugin
	 */
	public function sp_add_menu_pages() {

		add_menu_page(
			__( 'Saint Empaques' , 'saintpackages'), //page title
			__( 'Saint Empaques' , 'saintpackages'), //menu item title
			'manage_options', //access level
			'saint-packages-admin',	//page id
			[ $this, 'sp_create_admin_page' ], //item render function
			'',
			51 // menu item order
		);

//        add_submenu_page(
//            'saint-packages-admin', //parent
//            __( 'Empaques', 'saintpackages' ), //page title
//            __( 'Empaques', 'saintpackages' ), //menu item title
//            'manage_options', //access level
//            'saint-packages-admin-packages', //page id
//            [ $this, 'sp_admin_packages_view' ]
//        );

		add_action( 'admin_init', [ $this, 'page_init' ] );

	}

	/**
	 * Agregar el dominio de texto del plugin
	 */
	public function load_plugin_textdomain() {
		load_plugin_textdomain( 'saintpackages' , false , plugin_basename( dirname( __FILE__ ) . '/i18n/languages/' ) );
	}
	
    //Options page callback
    public function sp_create_admin_page() {
    	//set view params
		$this->options = [
            'sp_settings' => get_option( 'sp_settings' )
		];

        $sp_utilities = new sp_utilities();
        $sp_utilities->get_view( 'sp_admin' );
    }



	/**
	 * Register and add settings
	 */
	public function page_init() {
		
    	register_setting(
            'sp_settings', // Option group
            'sp_settings', // Option name
            array( $this, 'sanitize' ) // Sanitize
		);
    
    	add_settings_section(
            'sp_settings', // ID
            __( 'Ajustes Básicos' , 'saintpackages' ), // Title
            false, // Callback
            'saint-packages-admin&tab=display_sp_settings' // Page
		);
    
    	add_settings_field(
            'sp_sdk_url', // ID
            __( 'SDK URL' , 'saintpackages' ), // Title
            [ $this, 'sp_sdk_input_callback' ], // Callback
            'saint-packages-admin&tab=display_sp_settings', // Page
            'sp_settings' // Section
		);
    	
    	add_settings_field(
            'sp_sdk_user', // ID
            __( 'Usuario del SDK' , 'saintpackages' ), // Title
            [ $this, 'sp_sdk_user_input_callback' ], // Callback
            'saint-packages-admin&tab=display_sp_settings', // Page
            'sp_settings' // Section
    	);
    	
    	add_settings_field(
            'sp_sdk_user_password', // ID
            __( 'Contraseña para el Usuario del SDK' , 'saintpackages' ), // Title
            [ $this, 'sp_sdk_user_password_input_callback' ], // Callback
            'saint-packages-admin&tab=display_sp_settings', // Page
            'sp_settings' // Section
    	);

        add_settings_field(
            'sp_pagination', // ID
            __( 'Número de Items por Página' , 'saintpackages' ), // Title
            [ $this, 'sp_pagination_input_callback' ], // Callback
            'saint-packages-admin&tab=display_sp_settings', // Page
            'sp_settings' // Section
        );

        add_settings_field(
            'sp_create_tables', // ID
            __( 'Crear tablas del plugin' , 'saintpackages' ), // Title
            [ $this, 'sp_create_tables_input_callback' ], // Callback
            'saint-packages-admin&tab=display_sp_settings', // Page
            'sp_settings' // Section
        );

	}

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
	 * @return mixed
     */
    public function sanitize( $input ) {
		$new_input = [];
		if( isset( $input['sp_sdk_url'] ) )
			$new_input['sp_sdk_url'] = sanitize_text_field( $input['sp_sdk_url'] );

        if( isset( $input['sp_sdk_user'] ) )
			$new_input['sp_sdk_user'] = sanitize_text_field( $input['sp_sdk_user'] );

        if( isset( $input['sp_sdk_user_password'] ) )
			$new_input['sp_sdk_user_password'] = sanitize_text_field( $input['sp_sdk_user_password'] );

        if( isset( $input['sp_pagination'] ) )
            $new_input['sp_pagination'] = absint( $input['sp_pagination'] );

        return $new_input;
    }

	/**
	 * Get the settings option array and print one of its values
	 */
	public function sp_sdk_input_callback() {
		printf(
			'<input type="text" id="sp_sdk_url" name="sp_settings[sp_sdk_url]" value="%s" />',
			isset( $this->options['sp_settings']['sp_sdk_url'] ) ? esc_attr( $this->options['sp_settings']['sp_sdk_url']) : ''
		);
    }
    
    public function sp_sdk_user_input_callback() {
    	printf(
			'<input type="text" id="sp_sdk_user" name="sp_settings[sp_sdk_user]" value="%s" />',
			isset( $this->options['sp_settings']['sp_sdk_user'] ) ? esc_attr( $this->options['sp_settings']['sp_sdk_user']) : ''
		);
    }
    
    public function sp_sdk_user_password_input_callback() {
    	printf(
			'<input type="password" id="sp_sdk_user_password" name="sp_settings[sp_sdk_user_password]" value="%s" />',
			isset( $this->options['sp_settings']['sp_sdk_user_password'] ) ? esc_attr( $this->options['sp_settings']['sp_sdk_user_password']) : ''
		);
    }

    public function sp_pagination_input_callback() {
        printf(
            '<input type="number" min="1" id="sp_pagination" name="sp_settings[sp_pagination]" value="%s" />',
            isset( $this->options['sp_settings']['sp_pagination'] ) ? esc_attr( $this->options['sp_settings']['sp_pagination']) : ''
        );
    }

    public function sp_create_tables_input_callback() {

        global $wpdb;
        $table_name = $wpdb->prefix . "saintpackages";

        if ( $wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name ) {
            printf(
                '<button type="button" class="button button-primary" id="sp-create-tables-btn">'. __( 'Crear Tablas', 'saintpackages' ) . '</button>'
            );
        }
        else {
            printf(
                '<p>'. __( 'Tablas Creadas', 'saintpackages' ) . '</p>'
            );
        }

    }
    
}