<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class sp_utilities {

    /**
     * devuelve una vista del plugin
     * @param $view string nombre de la vista
     * @param $tmpl string nombre del template a mostrar
     * @param $tmpl_pdf string nombre del template en formato pdf a mostrar
     * @return mixed
     */
    public function get_view( $view = null, $tmpl = null, $tmpl_pdf = null ) {
        if ( isset( $view ) ) {

            $format = sp_utilities::sp_get_var( 'sp_format', 'get' );

            $template = '';

            switch ( $format ) {
                case 'pdf' :
                    if ( isset( $tmpl_pdf ) && $tmpl_pdf != '' ) {
                        $template = $tmpl_pdf . '_pdf';
                    }
                    else {
                        $template = 'default_pdf';
                    }
                    break;
                default :
                    if ( isset( $tmpl ) && $tmpl != '' ) {
                        $template = $tmpl;
                    }
                    else {
                        $template = 'default';
                    }
                    break;
            }


            $path = SAINT_PACKAGES_PATH . 'views/' . $view . '/view.php';
            include_once $path;
        }
        else {
            return __( 'Error, vista no especificada', 'saintpackages' );
        }
    }

    /**
     * devuelve un template del plugin
     * @param $view string nombre de la vista
     * @param $template string nombre del template
     * @param $data object items para el template
     *
     * @return mixed
     */
    public function get_template( $view = null, $template = null, $data = null ) {
        if ( isset( $view ) && isset( $template ) ) {

            $override_path = get_template_directory() . '/saintpackages/views/' . $view . '/' . $template . '.php';
            $items = $data;

            if ( !isset( $items ) || $items->Status != 0 ) {
                $items = [];
            }
            else {
                $items = $data->Data;
            }

            if ( $template == 'default' && file_exists( $override_path ) ) {
                include_once $override_path;
            }
            elseif ( $template != 'default' && file_exists( $override_path ) ) {
                include_once $override_path;
            }
            elseif ( $template == 'default_pdf' && file_exists( $override_path ) ) {
                include_once $override_path;
            }
            elseif ( $template != 'default_pdf' && file_exists( $override_path ) ) {
                include_once $override_path;
            }
            else {
                if ( $template == 'default_pdf' ) {
                    $template = 'default_pdf';
                }
                else {
                    $template = 'default';
                }
                $path = SAINT_PACKAGES_PATH . 'views/' . $view . '/templates/' . $template . '.php';
                include_once $path;
            }

        }
        else {
            return __( 'Error, vista o template no especificado', 'saintpackages' );
        }
    }

    /**
     * devuelve los parametros de configuracion del plugin
     * @return array
     */
    public static function get_config() {
        $config = [
            'sdk_url' => get_option( 'sp_settings' )[ 'sp_sdk_url' ],
            'sdk_user' => get_option( 'sp_settings' )[ 'sp_sdk_user' ],
            'sdk_user_password' => get_option( 'sp_settings' )[ 'sp_sdk_user_password' ],
        ];

        return $config;
    }

    /**
     * devuelve una variable recibida por POST o GET limpia
     * @param $var string variable recibida por POST o GET
     * @param $method string metodo mediante el cual se espera recibir la variable
     * @return string
     */
    public static function sp_get_var( $var, $method ) {

        switch ( $method ){
            case 'post' :
                $method = INPUT_POST;
                break;
            case 'get' :
                $method = INPUT_GET;
                break;
            default :
                $method = 0;
                break;
        }

        $clean = filter_input( $method, $var, FILTER_SANITIZE_STRING );
        return $clean;
    }

    /**
     * devuelve el codigo de retiro de una factura
     * @param $uniq_num string numero unico de la factura
     * @param $doc_num string numero del documento
     * @return mixed si la consulta es exitoza devuelve un array en caso contrario devuelve los mensajes de error
     */
    public static function get_withdrawal_code( $uniq_num, $doc_num ) {
        $item = '';
        try {

            $config = sp_utilities::get_config();
            $params = new sp_parametro_comun();

            $params->ExpresionFiltro = '[ParaEmpaque] = 1 AND [NumeroUnico] = ' . $uniq_num;
            $params->RegistroInicial = 0;
            $params->RegistrosPorPagina = 20;

            $client = new SoapClient( $config[ 'sdk_url' ] );
            $token = $_SESSION[ 'sp_user_token' ];
            $data = $client->Vta_Vta_LeerDetallesFacturaFull(
                [ "Numero" => $doc_num, "CodigoSucursal" => '00000', "_token" => $token ]
            );
            $status = json_decode( $data->Vta_Vta_LeerDetallesFacturaFullResult )->Status;
            if ( $status == -101 ) {
                $session = new sp_sessions();
                $token = $session->get_token();
                $data = $client->Vta_Vta_LeerDetallesFacturaFull(
                    [ "Numero" => $doc_num, "CodigoSucursal" => '00000', "_token" => $token ]
                );
                $item = json_decode( $data->Vta_Vta_LeerDetallesFacturaFullResult );
                if ( $item->Status == 0 ) {
                    $item = $item->Data->CodigoRetiro;
                }
                else {
                    $item = 0;
                }
            }
            else {
                $item = json_decode( $data->Vta_Vta_LeerDetallesFacturaFullResult );
                if ( $item->Status == 0 ) {
                    $item = $item->Data->CodigoRetiro;
                }
                else {
                    $item = 0;
                }
            }
        }
        catch( Exception $e ){
            $errors = new sp_errors();
            $errors->error_handler( 'sdk_rule', $e );
        }

        return $item;
    }

    /**
     * devuelve el estado de un empaque
     * @param $uniq_num int numero unico de la factura
     * @param $doc_num string numero del documento
     * @return int si el empaque esta asignado devuelve 1 en caso contrario devuelve 0
     */
    public static function get_package_status( $uniq_num, $doc_num ) {
        global $wpdb;

        $table_name = $wpdb->prefix . "saintpackages";

        $query = "SELECT status FROM $table_name WHERE uniq_num = $uniq_num AND doc_num = $doc_num";
        $result = $wpdb->get_var( $query );

        $status_get = sp_utilities::sp_get_var( 'status', 'get' );
        $status = 0;

        if ( isset( $status_get ) && !isset( $uniq_num ) && !isset( $doc_num ) && $status_get == 2 ) {
            $status = 2;
        }
        elseif( isset( $result ) ) {
            $status = $result;
        }
        else {
            $status = 0;
        }

        return $status;
    }

    /**
     * devuelve la informacion de un empacador
     * @param $uniq_num int numero unico de la factura
     * @param $doc_num string numero del documento
     * @return int si el empaque esta asignado devuelve 1 en caso contrario devuelve 0
     */
    public static function get_packers( $uniq_num, $doc_num ) {
        global $wpdb;

        $table_name = $wpdb->prefix . "saintpackages";

        $query = "SELECT server_id FROM $table_name WHERE uniq_num = $uniq_num AND doc_num = $doc_num";
        $result = $wpdb->get_var( $query );

        if( isset( $result ) ) {
            $server = $result;
        }
        else {
            $server = 0;
        }

        return $server;
    }

    /**
     * devuelve los numero unicos de las facturas asiganadas para el empaque
     * @return array devuelve un arreglo de numeros unicos
     */
    public static function get_assigned_packages() {
        global $wpdb;

        $table_name = $wpdb->prefix . "saintpackages";

        $query = "SELECT uniq_num FROM $table_name WHERE status = 1";
        $result = $wpdb->get_results( $query, 'OBJECT_K' );

        return $result;
    }

    /**
     * devuelve el paginador
     * @param $total int numero de elementos a paginar
     * @return html
     */
    public static function get_pagination( $total ) {
        if ( $total < 1 ) {
            return;
        }
        $pagination = get_option( 'sp_settings' )[ 'sp_pagination' ];

        $limit = $pagination;
        $pages = ceil($total / $pagination);

        if ( isset( $_GET[ 'sp_page' ] ) ) {
            $page = $_GET[ 'sp_page' ];
        } else {
            $page = 1;
        }

        $last = ( $pages - 1 ) * $limit;
        $offset = $page * $limit;
        $start = $offset + 1;
        $end = min( ( $offset + $limit ) , $total );
        ob_start();
        $con = $page;
        $con_limit = $con + 5;
        ?>
        <nav class="sp-pagination-container" aria-label="Page navigation">
            <ul class="sp-pagination pagination">

                <?php //pagination prev and first buttons?>
                <?php if( $page <= 1 ) :?>
                    <li class="sp-pagination-page disabled">
                        <span aria-hidden="true">&laquo;</span>
                    </li>
                    <li class="sp-pagination-page disabled">
                        <span><?php _e( 'Anterior' , 'saintpackages' );?></span>
                    </li>
                <?php else :?>
                    <li class="sp-pagination-page">
                        <a href="<?php echo esc_url( add_query_arg( array(
                            'sp_page' => 1
                        ) , get_permalink() ) );?>">
                            <span aria-hidden="true">&laquo;</span>
                        </a>
                    </li>
                    <li class="sp-pagination-page" >
                        <a href="<?php echo esc_url( add_query_arg( array(
                            'sp_start' => ( $start - ( $limit * 2 ) ) - 1,
                            'sp_page' => ($page - 1)
                        ) , get_permalink() ) );?>">
                            <span><?php _e( 'Anterior' , 'saintpackages' );?></span>
                        </a>
                    </li>
                <?php endif;?>
                <?php //end pagination prev and first buttons?>

                <?php //pagination pages?>
                    <?php if ( $page > 1 ) :?>
                        <li class="sp-pagination-page">
                            <span>...<span>
                        <li>
                    <?php endif;?>

                    <?php for ( $con ; $con < $con_limit ; $con++ ) :?>
                        <li class="sp-pagination-page <?php if ( $page == $con ) echo 'active';?>">
                            <a href="<?php echo esc_url( add_query_arg( array(
                                'sp_start' => ( ( $con - 1 ) * $limit ),
                                'sp_page' => ( $con )
                            ) , get_permalink() ) );?>">
                                <span><?php echo $con;?></span>
                            </a>
                        <li>
                    <?php if ( $con == $pages ) $con = $con_limit ;?>
                    <?php endfor;?>

                    <?php if ( $page < $pages ) :?>
                <li>
						<span>...<span>
                <li>
                    <?php endif;?>
                    <?php //end pagination pages?>

                    <?php //pagination next and last buttons?>
                    <?php if( $page >= $pages ) :?>
                <li class="sc-pagination-page disabled">
                    <span><?php _e( 'Siguiente' , 'saintpackages' );?></span>
                </li>
                <li class="sp-pagination-page disabled">
                    <span aria-hidden="true">&raquo;</span>
                </li>
            <?php else :?>
                <li class="sp-pagination-page">
                    <a href="<?php echo esc_url( add_query_arg( array(
                        'sp_start' => $start-1,
                        'sp_page' => ( $page + 1 )
                    ) , get_permalink() ) );?>">
                        <span><?php _e( 'Siguiente' , 'saintpackages' );?></span>
                    </a>
                </li>
                <li class="sp-pagination-page">
                    <a href="<?php echo esc_url( add_query_arg( array(
                        'sp_start' => $last,
                        'sp_page' => $pages
                    ) , get_permalink() ) );?>">
                        <span aria-hidden="true">&raquo;</span>
                    </a>
                </li>
            <?php endif;?>
                <?php //end pagination next and last buttons?>
            </ul>
        </nav>
        <?php
        return ob_get_clean();
    }


}