<?php
/**
 * Plugin Name: Saint Packages
 * Plugin URI: https://saintnet.com/
 * Description: Plugin para el empaque de productos utilizando los servicios del SDK de Saint de Venezuela
 * Author: Saint de Venezuela
 * Author URI: https://saintnet.com/
 * Version: 1.0.0
 * Text Domain: saintpackages
 * Domain Path: /i18n/languages/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */
if ( ! defined( 'ABSPATH' ) ) exit; //Exit if accessed directly.

if ( ! class_exists( 'saintpackages' ) ) {

    //Saint Packages Main Class
    class saintpackages {

        /**
         * inicializa el plugin
         */
        public function init() {
            add_action( 'init' ,  __CLASS__ . '::sp_constants' );
            add_action( 'init',  __CLASS__ . '::sp_includes', 1 );
            add_action( 'init', __CLASS__ . '::sp_session' , 2 );
            add_action( 'init' ,  __CLASS__ . '::ajax_handlers' );

            if( !is_admin() ) {
                add_action( 'init', __CLASS__ . '::add_site_styles' );
                add_action( 'init', __CLASS__ . '::add_site_scripts' );
            }

            if ( is_admin() ) {
                add_action( 'admin_menu',  __CLASS__ . '::sp_admin' );
                add_action( 'init' , __CLASS__ . '::add_admin_styles' );
            }
        }


        /**
         * incluye los estilos para las vista administrativas del plugin
         */
        public function add_admin_styles() {
            wp_enqueue_style( 'sp_admin_styles' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/css/sp_admin_styles.css' ) ) , false , '1.0.0' , 'all' );
        }

        /**
         * incluye los estilos para las vista del sitio del plugin
         */
        public function add_site_styles() {
            wp_enqueue_style( 'sp_jquery_ui_styles' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/css/jquery-ui.theme.min.css' ) ) , false , '1.0.0' , 'all' );
            wp_enqueue_style( 'sp_site_styles' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/css/sp_site_styles.css' ) ) , false , '1.0.0' , 'all' );
            wp_enqueue_style( 'dashicons' );

            wp_enqueue_style( 'sp_bootstrap' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/libs/bootstrap-3.3.6/css/bootstrap.min.css' ) ) , false , '1.0.0' , 'all' );
        }


        /**
         * incluye los scripts del sitio del plugin
         */
        public function add_site_scripts() {
            wp_enqueue_script( 'sp_bootstrap' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/libs/bootstrap-3.3.6/js/bootstrap.min.js' ) ), [ 'jquery' ] );
            wp_enqueue_script( 'sp_scripts' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/js/scripts.js' ) ), [ 'jquery', 'jquery-ui-core', 'jquery-ui-datepicker' ] );
            wp_enqueue_script( 'sp_qrcode' , plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/js/qrcode.min.js' ) ), [ 'jquery' ] );
        }

        /**
         * incluye los menus del plugin
         */
        public function sp_admin() {
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/admin/sp_admin.php';
            $sp_admin = new sp_admin();
            $sp_admin->sp_add_menu_pages();
        }

        /**
         * incluye las clases del plugin
         */
        public function sp_includes() {
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_errors.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_templates.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_utilities.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_sessions.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_models.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/sdk/models/sp_parametro_comun.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/sdk/models/sp_modelo_crear_empaques.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/shortcodes/sp_packages_shortcode.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/shortcodes/sp_packers_shortcode.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/assets/libs/dompdf/autoload.inc.php';
            include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_ajax_handler.php';
        }

        /**
         * incluye los handlers para las llamadas ajax
         */
        public function ajax_handlers() {
            if( !is_admin() ) {
                wp_enqueue_script( 'sp_pack_item', plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/js/sp_pack_item.js' ) ), [ 'jquery'] );
                wp_localize_script(
                    'sp_pack_item', 'sp_ajax_object_server',
                    [
                        'lang_aceptar' => __( 'Aceptar', 'saintpackages' ),
                        'ajax_url' => admin_url( 'admin-ajax.php' ),
                        'lang_empacar' => __( 'Empacar', 'saintpackages' ),
                        'lang_paquete_creado_para_entrega' => __( 'El paquete esta listo para la entrega', 'saintpackages' ),
                        'lang_codigo_servidor' => __( 'Código del Servidor', 'saintpackages' ),
                        'lang_error_al_crea_paquete_para_entrega' => __( 'Error al finalizar el paquete. Intente de nuevo', 'saintpackages' ),
                        'lang_error_codigo_servidor' => __( 'El código ingresado no coincide con el servidor asignado para el empaque', 'saintpackages' )
                    ]
                );
                wp_enqueue_script( 'sp_assign_package', plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/js/sp_assign_package.js' ) ), [ 'jquery'] );
                wp_localize_script(
                    'sp_assign_package', 'sp_ajax_object',
                    [
                        'ajax_url' => admin_url( 'admin-ajax.php' ),
                        'lang_aceptar' => __( 'Aceptar', 'saintpackages' ),
                        'lang_codigo_servidor' => __( 'Codigo del Servidor', 'saintpackages' ),
                        'lang_ingrese_codigo_valido' => __( 'Deve Ingresar un codigo valido', 'saintpackages' ),
                        'lang_servidor_no_comprobado' => __( 'Servidor no verificado. Por favor verifique', 'saintpackages' ),
                        'lang_paquete_asignado' => __( 'Paquete asignado con exito', 'saintpackages' )
                    ]
                );
                wp_enqueue_script( 'sp_filter_form', plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/js/sp_filter_form.js' ) ), [ 'jquery'] );

            }
            if( is_admin() ) {
                wp_enqueue_script( 'sp_admin_create_tables', plugins_url( plugin_basename( dirname( __FILE__ ) . '/assets/js/sp_admin_create_tables.js' ) ), [ 'jquery'] );
                wp_localize_script(
                    'sp_admin_create_tables', 'sp_ajax_object',
                    [
                        'ajax_url' => admin_url( 'admin-ajax.php' ),
                        'lang_creando_tablas' => __( 'Creando Tablas. Por Favor Espere...', 'saintpackages' ),
                        'lang_error_creando_tablas' => __( 'Error al crear las tablas', 'saintpackages' )
                    ]
                );
            }

            add_action( 'wp_ajax_nopriv_sp_pack_item', 'sp_ajax_handler::ajax_create_package' );
            add_action( 'wp_ajax_sp_pack_item', 'sp_ajax_handler::ajax_create_package' );
            add_action( 'wp_ajax_sp_assign_package', 'sp_ajax_handler::ajax_assign_package' );
            add_action( 'wp_ajax_nopriv_sp_assign_package', 'sp_ajax_handler::ajax_assign_package' );
            add_action( 'wp_ajax_sp_admin_create_table', 'sp_ajax_handler::ajax_create_plg_table' );
            add_action( 'wp_ajax_nopriv_sp_admin_create_table', 'sp_ajax_handler::ajax_create_plg_table' );


        }

        /**
         * get user token when start the plugin
         */
        public function sp_session() {
            session_start();
            if ( !isset( $_SESSION[ 'sp_user_token' ] ) || $_SESSION[ 'sp_user_token' ] == '' ) {
                try {
                    $config = sp_utilities::get_config();

                    $client = new SoapClient( $config[ 'sdk_url' ] );
                    $login = $client->SEG_LoginSaint(
                        [ "idUser" => $config[ 'sdk_user' ], "password" => $config[ 'sdk_user_password' ] ]
                    );

                    $token = json_decode( $login->SEG_LoginSaintResult )->Message;
                    $_SESSION[ 'sp_user_token' ] = $token;
                    var_dump( $token );
                }
                catch( Exception $e ) {
                    include_once ABSPATH . 'wp-content/plugins/saintpackages/includes/plg/sp_errors.php';
                    $error_handler = new sp_errors();
                    $error_handler->token_error_handler();
                }
            }
        }

        public function sp_constants() {
            define( 'SAINT_PACKAGES_PATH', plugin_dir_path( __FILE__ ) );
            define( 'SAINT_PACKAGES_URL', plugin_dir_url( __FILE__ ) );
        }

    }

    saintpackages::init();

}
